//
//  NSString+dUsefulStuff.m
//  dUsefulStuff
//
//  Created by Derek Clarkson on 25/09/11.
//  Copyright (c) 2011. All rights reserved.
//

#import "pthread.h"
#import "NSString+dUsefulStuff.h"

@implementation NSString (dUsefulStuff)

-(BOOL) readBooleanInto:(BOOL*) boolRef {
	
	if ([self caseInsensitiveCompare:@"yes"] == NSOrderedSame
		 || [self caseInsensitiveCompare:@"true"] == NSOrderedSame) {
		*boolRef = YES;
		return YES;
	}
	
	if ([self caseInsensitiveCompare:@"no"] == NSOrderedSame
		 || [self caseInsensitiveCompare:@"false"] == NSOrderedSame) {
		*boolRef = NO;
		return YES;
	}
	
	return NO;
}

// Date formatter used for logging.
static NSDateFormatter *dateFormatter;

-(void) logForObject:(id) object
				function:(NSString *) selector
					 line:(NSUInteger) line {
	
	
	// Sort out the date format. Assume that it is the same for all logging so cache the first instance.
	if (dateFormatter == nil) {
		dateFormatter = [[NSDateFormatter alloc] init];
		[dateFormatter setDateFormat:@"hh:mm:ss.SSS"];
	}
	
	NSString *formattedDate = [dateFormatter stringFromDate:[NSDate date]];
	NSString *processName = [[NSProcessInfo processInfo] processName];
	NSString *threadName = [NSThread currentThread].name;
	NSString *finalThreadName = threadName == nil || [threadName length] == 0 ? [NSString stringWithFormat:@"%x", pthread_mach_thread_np(pthread_self())] : threadName;
	
	// Synchrize logging to avoid log corruption by multiple theads writing at the same time.
	@synchronized ([NSProcessInfo processInfo]) {
		CFShow([NSString stringWithFormat:@"%1$@ <%2$@:%6$@> %3$@(%4$lu) %5$@", formattedDate, processName, selector, (unsigned long)line, self, finalThreadName]);
		fflush(stderr);
	}
}

+(void) logObject:(id) object
			function:(NSString *) selector
				 line:(NSUInteger) line
			 message:(NSString *) message {
	[message logForObject:object function:selector line:line];
}

@end
